@@ -1,12 +1,10 @@
 import os
 import requests
 
-from velocity.aws.handlers import LambdaHandler
-from velocity.aws.handlers import SqsHandler
-
 DEBUG = (os.environ.get('ENV') != 'production') \
      or (os.environ.get('DEBUG') == 'Y')
 
+
 # This is helpful for running HTTPS clients on lambda.
 if os.path.exists('/opt/python/ca-certificates.crt'):
     os.environ["REQUESTS_CA_BUNDLE"] = '/opt/python/ca-certificates.crt'
